@@ -1,13 +1,13 @@
 # pylint: disable-msg=W0622
 """cubicweb-tracker application packaging information
 
-Copyright (c) 2003-2009 LOGILAB S.A. (Paris, FRANCE).
+Copyright (c) 2003-2010 LOGILAB S.A. (Paris, FRANCE).
 http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 modname = 'tracker'
 distname = 'cubicweb-tracker'
 
-numversion = (1, 2, 0)
+numversion = (1, 4, 0)
 version = '.'.join(str(num) for num in numversion)
 
 license = 'LGPL'
@@ -16,10 +16,23 @@ author = 'LOGILAB S.A. (Paris, FRANCE)'
 author_email = 'contact@logilab.fr'
 
 short_desc = 'issue tracker component for the CubicWeb framework'
-long_desc = '''This CubicWeb component provides an issue tracker with projects,
-tickets and versions to group tickets. It can be used to manage projects.
+long_desc = '''Summary
+-------
 
-CubicWeb is a semantic web application framework, see http://www.cubicweb.org
+The `tracker` cube provides an issue tracker with projects, tickets and versions
+to group tickets. You can defines roadmap for a project by planning future
+versions.
+
+A link to subscribe to rss feed for published versions of project is
+located on each project toolbar.
+
+Usage
+-----
+
+- ProjectRoadmapView, displays all version
+
+- ProjectStatsView, displays the number of tickets for each status
+  ('done', 'validation pending', and so on)
 '''
 
 from os import listdir as _listdir
@@ -64,6 +77,6 @@ except OSError:
 
 
 __depends_cubes__ = {}
-__depends__ = {'cubicweb': '>= 3.5.0'}
+__depends__ = {'cubicweb': '>= 3.6.0'}
 __use__ = tuple(__depends_cubes__)
 
