@@ -10,15 +10,25 @@ from warnings import warn
 
 from logilab.common.decorators import cached
 
-from cubicweb.entities import AnyEntity
+from cubicweb.interfaces import ITree
+from cubicweb.mixins import TreeMixIn
+from cubicweb.entities import AnyEntity, fetch_config
 
 from cubes.tracker.entities import fixed_orderby_rql
 
-class Project(AnyEntity):
-    id = 'Project'
+class Project(TreeMixIn, AnyEntity):
+    __regid__ = 'Project'
+    __implements__ = AnyEntity.__implements__ + (ITree,)
     __permissions__ = ('developer', 'client')
+    fetch_attrs, fetch_order = fetch_config(('name', 'description', 'description_format',
+                                             'summary'))
+
     TICKET_DEFAULT_STATE_RESTR = 'S name IN ("created","identified","released","scheduled")'
 
+    tree_attribute = 'subproject_of'
+    parent_target = 'subject'
+    children_target = 'object'
+
     def dc_title(self):
         return self.name
 
@@ -65,22 +75,23 @@ class Project(AnyEntity):
         rql = 'Any V,N ORDERBY version_sort_value(N) %s ' \
               'WHERE V num N, V in_state S, S name IN (%s), ' \
               'V version_of P, P eid %%(p)s' % (order, ','.join(repr(s) for s in states))
-        return self.req.execute(rql, {'p': self.eid})
+        return self._cw.execute(rql, {'p': self.eid})
 
     # number of columns to display
     tickets_rql_nb_displayed_cols = 7
     sort_defs = (('in_state', 'S'), ('num', 'VN'), ('priority', 'PR'))
     def tickets_rql(self, limit=None):
-        rql = ('Any B, NOW - CD, NOW - BMD, U,PR,S,V,BD,VN,P,BT,CD,BMD,UL '
-               'GROUPBY B,CD,PR,S,V,U,VN,BD,P,BT,BMD,UL %s WHERE '
-               'B priority PR, B in_state S, B creation_date CD, '
-               'B description BD, '
-               'B title BT, B modification_date BMD, '
-               'B done_in V?, V num VN, '
-               'B created_by U?, U login UL, B concerns P, P eid %s'
-               ) % (fixed_orderby_rql(self.sort_defs), self.eid)
-        if limit:
-            rql += ' LIMIT %r' % limit
+        return ('Any B, NOW - CD, NOW - BMD, U,PR,S,V,BD,VN,P,BT,CD,BMD,UL '
+                'GROUPBY B,CD,PR,S,V,U,VN,BD,P,BT,BMD,UL '
+                '%s %s '
+                'WHERE B priority PR, B in_state S, B creation_date CD, '
+                'B description BD, '
+                'B title BT, B modification_date BMD, '
+                'B done_in V?, V num VN, '
+                'B created_by U?, U login UL, B concerns P, P eid %s'
+               ) % (fixed_orderby_rql(self.sort_defs),
+                    limit and ' LIMIT %r' % limit or '',
+                    self.eid)
         return rql
 
     def active_tickets_rql(self):
