@@ -2,7 +2,7 @@
 """tracker application'schema
 
 :organization: Logilab
-:copyright: 2003-2009 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
@@ -25,17 +25,15 @@ class Project(EntityType):
     """a project is a logical group of tasks/information which produce a final value. That
     may be a software or documentation project, a web site or whatever.
     """
-    permissions = {
+    __permissions__ = {
         'read':   ('managers', 'users', 'guests',),
         'add':    ('managers', 'staff',),
         'update': ('managers', 'staff', 'owners',),
         'delete': ('managers', 'owners'),
         }
     ## attributes
-    name      = String(required=True, fulltextindexed=True, unique=True,
-                       constraints=[SizeConstraint(64)])
-    summary   = String(fulltextindexed=True,
-                       constraints=[SizeConstraint(128)],
+    name      = String(required=True, fulltextindexed=True, unique=True, maxsize=64)
+    summary   = String(fulltextindexed=True, maxsize=128,
                        description=_('one line description of the project'))
 
     description = RichString(fulltextindexed=True, default_format='text/rest',
@@ -43,10 +41,11 @@ class Project(EntityType):
 
     ## relations
     uses = SubjectRelation('Project', description=_('project\'s dependencies'))
+    subproject_of = SubjectRelation('Project', composite='object', cardinality='?*')
 
 
 class uses(RelationType):
-    permissions = {
+    __permissions__ = {
         'read':   ('managers', 'users', 'guests'),
         'add':    ('managers', RRQLExpression('U has_update_permission S', 'S'),),
         'delete': ('managers', RRQLExpression('U has_update_permission S', 'S'),),
@@ -55,7 +54,7 @@ class uses(RelationType):
 
 class Version(WorkflowableEntityType):
     """a version is defining the content of a particular project's release"""
-    permissions = {
+    __permissions__ = {
         'read':   ('managers', 'users', 'guests',),
         # right to add Version is actually granted on the version_of relation
         'add':    ('managers', 'users'),
@@ -76,13 +75,14 @@ class Version(WorkflowableEntityType):
     ## relations
     version_of = SubjectRelation('Project', cardinality='1*', composite='object')
     todo_by = SubjectRelation('CWUser',
-                              constraints=[RQLConstraint('O in_state ST, ST name "activated"')],
+                              constraints=[RQLConstraint('O in_state ST, ST name "activated"'),
+                                           RQLVocabularyConstraint('O in_group G, G name "staff"')],
                               description=_('users responsible for this version'))
     conflicts = SubjectRelation('Version',
-                                constraints=[RQLVocabularyConstraint('S version_of PS, O version_of PO, PS uses PO')],
+                                constraints=[RQLVocabularyConstraint('S version_of PS, O version_of PO, EXISTS(PS uses PO) OR EXISTS(PO subproject_of PS)')],
                                 description=_('client project\'s version conflicting with this version'))
     depends_on = SubjectRelation('Version',
-                                 constraints=[RQLVocabularyConstraint('S version_of PS, O version_of PO, PS uses PO')],
+                                 constraints=[RQLVocabularyConstraint('S version_of PS, O version_of PO, EXISTS(PS uses PO) OR EXISTS(PO subproject_of PS)')],
                                  description=_('client project\'s version dependency for this version'))
 
 
@@ -90,7 +90,7 @@ class Ticket(WorkflowableEntityType):
     """a ticket is representing some kind of work to do (or done) on a project
     (bug fix, feature request...)
     """
-    permissions = {
+    __permissions__ = {
         'read':   ('managers', 'users', 'guests',),
         # right to add Ticket is actually granted on the concerns relation
         'add':    ('managers', 'users',),
@@ -131,8 +131,11 @@ class Ticket(WorkflowableEntityType):
                                    constraints=[RQLConstraint('S concerns P, O concerns P')])
     depends_on = SubjectRelation('Ticket',
                                  description=_("ticket which has to be done to complete this one"),
-                                 constraints=[RQLVocabularyConstraint('S concerns P, EXISTS(O concerns P) '
-                                                                      'OR EXISTS(O concerns P2, P uses P2)')])
+                                 constraints=[RQLVocabularyConstraint(
+                                     'S concerns P, EXISTS(O concerns P) '
+                                     'OR EXISTS(O concerns PS, '
+                                     'EXISTS(P uses P2) OR '
+                                     'EXISTS(P2 subproject_of P))')])
 
 
 
@@ -141,13 +144,12 @@ class Ticket(WorkflowableEntityType):
 # extra relation definitions ##################################################
 
 class see_also(RelationDefinition):
-    symetric = True
+    symmetric = True
     subject = ('Project', 'Ticket')
     object = ('Project', 'Ticket')
 
 
-class missing_require_permission(RelationDefinition):
-    name = 'require_permission'
+class require_permission(RelationDefinition):
     subject = ('Project', 'Version', 'Ticket')
     object = 'CWPermission'
 
@@ -157,7 +159,7 @@ class has_group_permission(RelationDefinition):
     """
     subject = 'CWUser'
     object = 'CWPermission'
-    permissions = {
+    __permissions__ = {
         'read':   ('managers', 'users', 'guests'),
         'add':    ('managers',),
         'delete': ('managers',),
@@ -165,27 +167,36 @@ class has_group_permission(RelationDefinition):
 
 # relation types permissions ##################################################
 
+class subproject_of(RelationType):
+    """link a ticket to the version in which it has been done"""
+    inlined = True
+    __permissions__ = {
+        'read':   ('managers', 'users', 'guests'),
+        'add':    ('managers', 'staff', RRQLExpression('U has_update_permission O', 'O')),
+        'delete': ('managers', 'staff', RRQLExpression('U has_update_permission O', 'O')),
+    }
+
 class version_of(RelationType):
     """link a version to its project. A version is necessarily linked to one and
     only one project.
     """
     inlined = True
-    permissions = {
+    __permissions__ = {
         'read':   ('managers', 'users', 'guests',),
         'add':    ('managers', 'staff', oexpr('client'),),
         'delete': ('managers', ),
         }
 
 class todo_by(RelationType):
-    permissions = {
+    __permissions__ = {
         'read':   ('managers', 'users', 'guests'),
         'add':    ('managers',),
         'delete': ('managers',),
         }
 
 class conflicts(RelationType):
-    symetric = True
-    permissions = {
+    symmetric = True
+    __permissions__ = {
         'read':   ('managers', 'users', 'guests'),
         'add':    ('managers', 'staff', sexpr('developer'),),
         'delete': ('managers', 'staff', sexpr('developer'),),
@@ -196,7 +207,7 @@ class concerns(RelationType):
     only one project.
     """
     inlined = True
-    permissions = {
+    __permissions__ = {
         'read':   ('managers', 'users', 'guests'),
         'add':    ('managers', 'staff', oexpr('developer', 'client'),),
         'delete': ('managers', 'staff',),
@@ -205,7 +216,7 @@ class concerns(RelationType):
 class done_in(RelationType):
     """link a ticket to the version in which it has been done"""
     inlined = True
-    permissions = {
+    __permissions__ = {
         'read':   ('managers', 'users', 'guests'),
         # XXX should require permission on the ticket or on the version, or both?
         # XXX should check the state of a ticket
@@ -214,7 +225,7 @@ class done_in(RelationType):
     }
 
 class appeared_in(RelationType):
-    permissions = {
+    __permissions__ = {
         'read':   ('managers', 'users', 'guests'),
         # XXX should require permission on the ticket or on the version, or both?
         'add':    ('managers', 'staff', restricted_oexpr('O in_state ST, ST name "published"', 'developer', 'client'),),
@@ -222,7 +233,7 @@ class appeared_in(RelationType):
     }
 
 class depends_on(RelationType):
-    permissions = {
+    __permissions__ = {
         'read':   ('managers', 'users', 'guests'),
         'add':    ('managers', 'staff', sexpr('developer', 'client'),),
         'delete': ('managers', 'staff', sexpr('developer', 'client'),),
