@@ -3,12 +3,12 @@ from os.path import dirname, join, abspath
 from logilab.common.decorators import cached
 
 from cubicweb import MultiSourcesError
-from cubicweb.devtools import TestServerConfiguration, init_test_database
-from cubicweb.devtools.apptest import RepositoryBasedTC
+from cubicweb.devtools import TestServerConfiguration, ApptestConfiguration, init_test_database
+from cubicweb.devtools.testlib import CubicWebTC
 
 #from unittest_querier_planner import do_monkey_patch, undo_monkey_patch
 
-class ThreeSourcesConfiguration(TestServerConfiguration):
+class ThreeSourcesConfiguration(ApptestConfiguration):
     @cached
     def sources(self):
         res = TestServerConfiguration.sources(self)
@@ -60,16 +60,15 @@ class External2SourceConfiguration(TestServerConfiguration):
                          }
         return res
 
-repo2, cnx2 = init_test_database('sqlite', config=ExternalSourceConfiguration('data'))
+repo2, cnx2 = init_test_database(config=ExternalSourceConfiguration('data'))
 cu = cnx2.cursor()
 ep1eid = cu.execute('INSERT Project X: X name "Extern project 1"')[0][0]
 ep1v1eid = cu.execute('INSERT Version V: V num "0.1.0", V version_of X WHERE X name "Extern project 1"')[0][0]
 ep2eid = cu.execute('INSERT Project X: X name "Extern project 2"')[0][0]
 ep2v1eid = cu.execute('INSERT Version V: V num "0.1.0", V version_of X WHERE X name "Extern project 2"')[0][0]
 cnx2.commit()
-#print 'extern project eids', ep1eid, ep2eid
 
-repo3, cnx3 = init_test_database('sqlite', config=External2SourceConfiguration('data'))
+repo3, cnx3 = init_test_database(config=External2SourceConfiguration('data'))
 cu3 = cnx3.cursor()
 e2p1eid = cu3.execute('INSERT Project X: X name "Extern2 project 1"')[0][0]
 cnx3.commit()
@@ -82,11 +81,11 @@ PyroRQLSource.get_connection = lambda x: x.uri == 'extern' and cnx2 or cnx3
 from cubicweb.dbapi import Connection
 Connection.close = lambda x: None
 
-class BaseMSTC(RepositoryBasedTC):
-    repo_config = ThreeSourcesConfiguration('data')
+class BaseMSTC(CubicWebTC):
+    config = ThreeSourcesConfiguration('data')
 
     def setUp(self):
-        RepositoryBasedTC.setUp(self)
+        CubicWebTC.setUp(self)
         self.extern = self.repo.sources_by_uri['extern']
         # trigger import from external source since sqlite doesn't support
         # concurrent access to the database
