@@ -1,13 +1,13 @@
 """some utilities for testing tracker security
 
 :organization: Logilab
-:copyright: 2008-2009 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+:copyright: 2008-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 :contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
 """
 __docformat__ = "restructuredtext en"
 
 from cubicweb.devtools import BaseApptestConfiguration
-from cubicweb.devtools.apptest import RepositoryBasedTC
+from cubicweb.devtools.testlib import CubicWebTC
 from cubicweb import Unauthorized, ValidationError
 
 def ptransitions(entity):
@@ -49,11 +49,12 @@ class TrackerTCMixIn(object):
         """
         pname = unicode(pname)
         plabel = plabel and unicode(plabel) or unicode(group)
-        peid = self.execute('INSERT CWPermission X: X name %%(pname)s, X label %%(plabel)s,'
-                            'X require_group G, '
-                            'P require_permission X '
-                            'WHERE G name %%(group)s, P is %s, P name %%(project)s' % etype,
-                            locals())[0][0]
+        peid = self.session.unsafe_execute(
+            'INSERT CWPermission X: X name %%(pname)s, X label %%(plabel)s,'
+            'X require_group G, '
+            'P require_permission X '
+            'WHERE G name %%(group)s, P is %s, P name %%(project)s' % etype,
+            locals())[0][0]
         return peid
 
     def assertModificationDateGreater(self, entity, olddate):
@@ -64,16 +65,22 @@ class TrackerTCMixIn(object):
         self.assertListEquals(ptransitions(entity), sorted(expected))
 
 
-class SecurityTC(TrackerTCMixIn, RepositoryBasedTC):
+class TrackerBaseTC(TrackerTCMixIn, CubicWebTC):
+    def setup_database(self):
+        self.cubicweb = self.request().create_entity('Project', name=u'cubicweb',
+                                        description=u"cubicweb c'est beau")
+
+
+class SecurityTC(TrackerTCMixIn, CubicWebTC):
     repo_config = BaseApptestConfiguration('data')
     _initialized = False
     def setUp(self):
-        RepositoryBasedTC.setUp(self)
-        self.__cnxs = {}
+        CubicWebTC.setUp(self)
+        self.__cnxs = {'admin': self.cnx}
         # trick to avoid costly initialization for each test
         if not SecurityTC._initialized:
             # implicitly test manager can add some entities
-            self.execute(*create_project_rql("cubicweb"))
+            self.__class__.cubicweb = self.execute(*create_project_rql("cubicweb")).get_entity(0, 0)
             self.execute(*create_project_rql("projet2"))
             self.execute('INSERT CWGroup X: X name "cubicwebdevelopers"')
             self.execute('INSERT CWGroup X: X name "cubicwebclients"')
@@ -85,7 +92,7 @@ class SecurityTC(TrackerTCMixIn, RepositoryBasedTC):
             self.create_user('prj1developer', groups=('users', 'cubicwebdevelopers',))
             self.create_user('prj1client', groups=('users', 'cubicwebclients'))
             self.maxeid = self.execute('Any MAX(X)')[0][0]
-            SecurityTC._initialized = True
+            #SecurityTC._initialized = True
             cachedperms = self.execute('Any UL, PN WHERE U has_group_permission P, U login UL, P label PN')
             self.assertEquals(len(cachedperms), 2)
             self.assertEquals(dict(cachedperms),
