@@ -12,87 +12,65 @@ from logilab.common import table as _table
 
 from cubicweb.schema import display_name
 from cubicweb.view import EntityView, EntityStartupView
-from cubicweb.selectors import (implements, has_related_entities, rql_condition,
-                                none_rset, anonymous_user, authenticated_user)
-from cubicweb.common import tags
-from cubicweb.web import action, component
-from cubicweb.web.views import primary, tabs, baseviews
+from cubicweb.selectors import (implements, has_related_entities, none_rset,
+                                anonymous_user, authenticated_user, score_entity)
+from cubicweb import tags
+from cubicweb.web import component, uicfg
+from cubicweb.web.views import tabs, baseviews
+
+_pvdc = uicfg.primaryview_display_ctrl
+_pvdc.tag_attribute(('Project', 'summary'), {'showlabel': False})
+_pvdc.tag_attribute(('Project', 'description'), {'showlabel': False})
 
 # primary view and tabs ########################################################
 
-class ProjectPrimaryView(tabs.TabsMixin, primary.PrimaryView):
+class ProjectPrimaryView(tabs.TabbedPrimaryView):
     __select__ = implements('Project')
 
     tabs = [_('projectinfo_tab'), _('projectroadmap_tab'), _('projecttickets_tab')]
     default_tab = 'projectinfo_tab'
 
-    def render_entity_title(self, entity):
-        self.w(u'<div class="projectTitleGroup">%s %s</div>' % (
-            entity.dc_type().capitalize(),
-            entity.view('reledit', rtype='name',
-                        role='subject', reload=True)))
-        self.w(u'<br/>')
 
-    def cell_call(self, row, col):
-        entity = self.complete_entity(row, col)
-        self.render_entity_title(entity)
-        self.render_tabs(self.tabs, self.default_tab, entity)
+# configure projectinfotab
+_pvs = uicfg.primaryview_section
+_pvs.tag_attribute(('Project', 'name'), 'hidden')
+# XXX keep '*', not Project to match other target types added in eg forge
+_pvs.tag_subject_of(('Project', 'uses', '*'), 'attributes')
+_pvs.tag_object_of(('Project', 'uses', '*'), 'attributes')
+_pvs.tag_object_of(('Project', 'subproject_of', '*'), 'hidden')
+_pvs.tag_subject_of(('*', 'subproject_of', 'Project'), 'hidden')
 
-
-class ProjectInfoTab(primary.PrimaryView):
-    id = 'projectinfo_tab'
+class ProjectInfoTab(tabs.PrimaryTab):
+    __regid__ = 'projectinfo_tab'
     __select__ = implements('Project')
 
     title = None # should not appear in possible views
-    attribute_relations = [('summary', 'subject'),
-                           ('description', 'subject'),
-                           ('uses', 'subject'),
-                           ('uses', 'object')]
-
-    def is_primary(self):
-        return True
-
-    def render_entity_title(self, entity):
-        pass
-
-    def render_entity_attributes(self, entity):
-        w = self.w
-        w(u'<div class="entityDescr">')
-        for rtype, role in self.attribute_relations:
-            value = entity.view('reledit', rtype=rtype, role=role)
-            if value:
-                self.field(display_name(self.req, rtype, role), value,
-                           show_label=True, w=self.w, tr=False)
-        w(u'</div>')
-
-    def render_entity_relations(self, entity):
-        pass
 
 
 class ProjectRoadmapTab(EntityView):
     """display the latest published version and in preparation version"""
-    id = 'projectroadmap_tab'
+    __regid__ = 'projectroadmap_tab'
     __select__ = (anonymous_user() & implements('Project') &
                   has_related_entities('version_of', 'object'))
 
     title = None # should not appear in possible views
 
     def cell_call(self, row, col):
-        self.rset.get_entity(row, col).view('roadmap', w=self.w)
+        self.cw_rset.get_entity(row, col).view('roadmap', w=self.w)
 
 
 class ProjectTicketsTab(EntityView):
-    id = 'projecttickets_tab'
+    __regid__ = 'projecttickets_tab'
     __select__ = implements('Project')
 
     title = None # should not appear in possible views
 
     def cell_call(self, row, col):
-        entity = self.entity(row, col)
+        entity = self.cw_rset.get_entity(row, col)
         # optimization: prefetch project's to fill entity / relations cache
         entity.reverse_version_of
-        rset = self.req.execute(entity.tickets_rql(limit=1))
-        self.req.form['actualrql'] = entity.active_tickets_rql()
+        rset = self._cw.execute(entity.tickets_rql(limit=1))
+        self._cw.form['actualrql'] = entity.active_tickets_rql()
         self.wview('editable-initialtable', rset, 'null',
                    subvid='incontext', displayactions=1,
                    divid='tickets%s' % entity.eid,
@@ -103,7 +81,7 @@ class ProjectTicketsTab(EntityView):
 
 class ProjectRoadmapVComponent(component.EntityVComponent):
     """display the latest published version and in preparation version"""
-    id = 'roadmap'
+    __regid__ = 'roadmap'
     __select__ = (component.EntityVComponent.__select__ &
                   authenticated_user() & implements('Project') &
                   has_related_entities('version_of', 'object'))
@@ -112,14 +90,34 @@ class ProjectRoadmapVComponent(component.EntityVComponent):
     order = 10
 
     def cell_call(self, row, col, view=None):
-        self.rset.get_entity(row, col).view('roadmap', w=self.w)
+        self.cw_rset.get_entity(row, col).view('roadmap', w=self.w)
+
+
+class ProjectTreeVComponent(component.EntityVComponent):
+    __regid__ = 'projecttree'
+    title = _('project tree')
+    __select__ = (component.EntityVComponent.__select__ &
+                  implements('Project') &
+                  score_entity(lambda x: x.children()))
+    context = 'navcontentbottom'
+
+    def cell_call(self, row, col, view=None):
+        entity = self.cw_rset.get_entity(row, col)
+        rset = entity.children(entities=False)
+        if rset:
+            self.w(u'<div class="section">')
+            self.w(tags.h2(self._cw._('Project tree')))
+            treeid = 'project_tree_%s' % entity.eid
+            self.w(self.view('treeview', rset=rset, treeid=treeid,
+                             initial_thru_ajax=True))
+            self.w(u'</div>')
 
 
 # secondary views ##############################################################
 
 class ProjectRoadmapView(EntityView):
     """display the latest published version and in preparation version"""
-    id = 'roadmap'
+    __regid__ = 'roadmap'
     __select__ = (implements('Project') &
                   has_related_entities('version_of', 'object'))
     title = None # should not appear in possible views
@@ -130,20 +128,20 @@ class ProjectRoadmapView(EntityView):
 
     def cell_call(self, row, col):
         self.w(u'<div class="section">')
-        entity = self.rset.get_entity(row, col)
+        entity = self.cw_rset.get_entity(row, col)
         currentversion = entity.latest_version()
         if currentversion:
-            self.w(self.req._('latest published version:'))
+            self.w(self._cw._('latest published version:'))
             self.w(u'&nbsp;')
             currentversion.view('incontext', w=self.w)
             self.w(u'<br/>')
-        rset = self.req.execute(self.rql, {'x': entity.eid}, 'x')
+        rset = self._cw.execute(self.rql, {'x': entity.eid}, 'x')
         if rset:
             self.wview('ic_progress_table_view', rset)
         allversionsrql = entity.related_rql('version_of', 'object') % {'x': entity.eid}
         self.w('<a href="%s">%s</a>'
-               % (xml_escape(self.build_url(vid='list', rql=allversionsrql)),
-                  self.req._('view all versions')))
+               % (xml_escape(self._cw.build_url(vid='list', rql=allversionsrql)),
+                  self._cw._('view all versions')))
         self.w(u'</div>')
 
 
@@ -154,7 +152,7 @@ class ProjectOutOfContextView(baseviews.OutOfContextView):
     __select__ = implements('Project')
 
     def cell_call(self, row, col):
-        entity = self.entity(row, col)
+        entity = self.cw_rset.get_entity(row, col)
         self.w(tags.a(entity.name, href=entity.absolute_url()))
         # no summary on ext project
         if getattr(entity, 'summary', None):
@@ -167,18 +165,19 @@ class ProjectOutOfContextView(baseviews.OutOfContextView):
 class ProjectStatsView(EntityStartupView):
     """Some statistics : how many bugs, sorted by status, indexed by projects
     """
-    id = 'stats'
+    __regid__ = 'stats'
     __select__ = none_rset() | implements('Project')
     title = _('projects statistics')
     default_rql = 'Any P,PN WHERE P name PN, P is Project'
 
     def call(self, sort_col=None):
         w = self.w
-        req = self.req
-        if self.rset is None:
-            self.rset = req.execute(self.default_rql)
+        req = self._cw
+        req.add_css('cubes.tracker.stats.css')
+        if self.cw_rset is None:
+            self.cw_rset = req.execute(self.default_rql)
         table = _table.Table()
-        statuslist = [row[0] for row in self.req.execute('DISTINCT Any N WHERE S name N, X in_state S, X is Ticket')]
+        statuslist = [row[0] for row in self._cw.execute('DISTINCT Any N WHERE S name N, X in_state S, X is Ticket')]
         severities = ['minor', 'normal', 'important']
         table.create_columns(statuslist + severities + ['Total'])
         nb_cols = len(table.col_names)
@@ -186,7 +185,7 @@ class ProjectStatsView(EntityStartupView):
         stylesheet = _table.TableStyleSheet()
         # fill table
         i = -1
-        for row in self.rset:
+        for row in self.cw_rset:
             i += 1
             eid = row[0]
             row = []
@@ -202,17 +201,17 @@ class ProjectStatsView(EntityStartupView):
                 total += nbtickets
                 row.append(nbtickets)
             row.append(total)
-            table.append_row(row, xml_escape(self.entity(i).name))
+            table.append_row(row, xml_escape(self.cw_rset.get_entity(i, 0).name))
             assert len(row) == nb_cols
         # sort table according to sort_col if wanted
-        sort_col = sort_col or self.req.form.get('sort_col', '')
+        sort_col = sort_col or self._cw.form.get('sort_col', '')
         if sort_col:
             table.sort_by_column_id(sort_col, method='desc')
         else:
             table.sort_by_column_index(0)
         # append a row to compute sums over rows and add appropriate
         # stylesheet rules for that
-        if len(self.rset) > 1:
+        if len(self.cw_rset) > 1:
             table.append_row([0] * nb_cols, 'Total')
             nb_rows = len(table.row_names)
             for i in range(nb_cols):
@@ -222,9 +221,9 @@ class ProjectStatsView(EntityStartupView):
         w(u'<table class="stats" cellpadding="5">')
         w(u'<tr>')
         for col in [''] + table.col_names:
-            url = self.build_url(vid='stats', sort_col=col,
+            url = self._cw.build_url(vid='stats', sort_col=col,
                                  __force_display=1,
-                                 rql=self.rset.printable_rql())
+                                 rql=self.cw_rset.printable_rql())
             self.w(u'<th><a href="%s">%s</a></th>\n' % (xml_escape(url), col))
         self.w(u'</tr>')
         for row_name, row, index in zip(table.row_names, table.data,
@@ -236,10 +235,32 @@ class ProjectStatsView(EntityStartupView):
             if index == len(table.data) - 1:
                 w(u'<td>%s</td>' % row_name)
             else:
-                url = self.build_url('project/%s' % self.req.url_quote(row_name))
+                url = self._cw.build_url('project/%s' % self._cw.url_quote(row_name))
                 self.w(u'<td><a href="%s">%s</a></td>' % (xml_escape(url), row_name))
             for cell_data in row:
                 w(u'<td>%s</td>' % cell_data)
             w(u'</tr>')
         w(u'</table>')
 
+
+class SubscribeToReleasesComponent(component.EntityVComponent):
+    """link to subscribe to rss feed for published versions of project
+    """
+    __regid__ = 'projectreleasesubscriberss'
+    __select__ = (component.EntityVComponent.__select__ &
+                  implements('Project'))
+    context = 'ctxtoolbar'
+
+    def cell_call(self, row, col, view=None):
+        entity = self.cw_rset.get_entity(row, col)
+        label = self._cw._(u'Subscribe to project releases')
+        logo = u'<img src="%s" alt="%s"/>' % (
+            self._cw.external_resource('RSS_LOGO_16'), label)
+        rql = 'Any V, VN ORDERBY VN DESC WHERE V version_of P, P eid %s, ' \
+              'V in_state S, S name "published", V num VN' % entity.eid
+        # XXX <project>/versions/rss ?
+        url = self._cw.build_url('view', vid='rss', rql=rql)
+        self.w(u'<a href="%s" title="%s" class="toolbarButton">%s</a>' % (
+            xml_escape(url), label, logo))
+
+
